==> igniteui-angular-charts-18.1.1.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afu != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afu != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afu == null) {
                if (this.ad != null) {
                    c.afu = this.ad;
                }
                else {
                    c.afu = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afu != null) {
                this.ad = c.afu;
                c.afu = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };

==> igniteui-angular-charts-18.2.0.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ae = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.h = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.agc != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.aa = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.i("ShowGridlines", 2, a.agc != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.q = function (a, b) {
        var c = a;
        if (this.d(b, "ShowGridlines")) {
            if (c.agc == null) {
                if (this.ae != null) {
                    c.agc = this.ae;
                }
                else {
                    c.agc = c.dataChart.aaq;
                }
            }
        }
        else {
            if (c.agc != null) {
                this.ae = c.agc;
                c.agc = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };
